@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkGeoTerrain2D extends vtkGeoTerrain
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -37,7 +37,7 @@ public class vtkGeoTerrain2D extends vtkGeoTerrain
 
     if (temp == 0) return null;
     return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkGeoTerrain2D() { super(); }
 
